severity = brutal
verbose = 8
exclude = CodeLayout::RequireUseUTF8 Compatibility::PodMinimumVersion Documentation::RequirePODUseEncodingUTF8 Editor::RequireEmacsFileVariables Miscellanea::RequireRcsKeywords Modules::RequireExplicitPackage CodeLayout::ProhibitHashBarewords Tics::ProhibitLongLines

[CodeLayout::RequireTidyCode]
perltidyrc = xt/author/perltidy.rc

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = diagnostics feature perlversion strict warnings utf8

[Documentation::PodSpelling]
stop_words = bugtracker Perldoc perldoc

[Documentation::RequirePodSections]
lib_sections    = NAME | VERSION | DESCRIPTION | SYNOPSIS | COPYRIGHT AND LICENSE
script_sections = NAME | USAGE | OPTIONS | EXIT STATUS | COPYRIGHT AND LICENSE

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = Any::Moose::any_moose Any::Moose::blessed Any::Moose::extends Any::Moose::has Any::Moose::override Any::Moose::with Mouse::extends

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w+

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Any::Moose Mouse

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Any::Moose Mouse
